//**************************************************************************//
// This DLL plugin automatically reboot the server after a fixed amount of  //
// time and only if the server contains less than a configurable number of  //
// Players.                                                                 //
//                                                                          //
// AutoReboot version 1.0.1                                                 //
//                                                                          //
// This source code is free and freely modifiable.                          //
//                                                                          //
// Author: Giovanni "EvilCow" Di Sirio                                      //
//**************************************************************************//

library AutoReboot;

{%File 'Readme.txt'}

uses
  Windows,
  SysUtils,
  Classes,
  Dialogs,
  PluginsInterface in 'PluginsInterface.pas';

{$R *.RES}

var
  // Server APIs.
  // Note: these APIs are supposed to be invoked ONLY in event handlers so call
  // them into a separate thread is NOT a good idea.
  ServerAPI: TMonitorServices;
  StartTime: TDateTime;
  Timeout: Extended;

//
// This event handler is called at Plugin load time once.
procedure OnInit(var _ServerAPI: TMonitorServices); stdcall;
var
  buf: array [0..7] of Char;
begin
  ServerAPI := _ServerAPI;
  ServerAPI.GetConfigString('AutoReboot', 'Timeout', buf, sizeof(buf));
  Timeout := StrToIntDef(buf, 0) / 24;
end;

//
// This handler is called at plugin unload time once.
procedure OnExit; stdcall;
begin
end;

//
// This handler is called when the dedicated server starts.
procedure OnServerStart(var _ServerConfig: TServerData); stdcall;
begin
  StartTime := Now;
end;

//
// This handler is called when the dedicated server stops or crashes.
procedure OnServerStop; stdcall;
begin
end;

//
// This handler is called when a mission starts.
procedure OnMissionStart(var _MissionData: TMissionData); stdcall;
begin
end;

//
// This handler is called when a mission ends.
procedure OnMissionStop; stdcall;
begin
  if TimeOut > 0 then
  begin
    if (Timeout < Now - StartTime) and
       (ServerAPI.GetPlayersCount = 0) then
      ServerAPI.Reboot;
  end;
end;

//
// This handler is called when a player connects to the server.
procedure OnConnect(var Player: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player disconnect from the server.
procedure OnDisconnect(var Player: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player joins the game.
procedure OnJoin(var Player: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player leaves the game.
procedure OnLeave(var Player: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player kills another player.
procedure OnDestroy(var Player1, Player2: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player kills a team mate.
procedure OnTeamKill(var Player1, Player2: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player suicides.
procedure OnSuicide(var Player: TPlayerData); stdcall;
begin
end;

//
// This handler is called when a player type something in **public** chat.
procedure OnChat(var Player: TPlayerData; Cmd: PChar); stdcall;
begin
end;

//
// This handler is called every second **while** the server is running, do not
// make long stuff here or the monitor will slow down the system (it is called
// LAG too).
procedure OnTimer; stdcall;
begin
end;

exports
  OnInit         name '_OnInit@4',
  OnExit         name '_OnExit@0',
  OnServerStart  name '_OnServerStart@4',
  OnServerStop   name '_OnServerStop@0',
  OnMissionStart name '_OnMissionStart@4',
  OnMissionStop  name '_OnMissionStop@0',
  OnConnect      name '_OnConnect@4',
  OnDisconnect   name '_OnDisconnect@4',
  OnJoin         name '_OnJoin@4',
  OnLeave        name '_OnLeave@4',
  OnDestroy      name '_OnDestroy@8',
  OnTeamKill     name '_OnTeamKill@8',
  OnSuicide      name '_OnSuicide@4',
  OnChat         name '_OnChat@8',
  OnTimer        name '_Ontimer@0';

procedure DLLHandler(Reason: Integer);
begin
  // DLL System events here,
  // Reason can be one of: DLL_PROCESS_DETACH, DLL_THREAD_ATTACH, DLL_THREAD_DETACH
  // but only DLL_PROCESS_DETACH is of some interest because the monitor is single
  // threaded.
  if Reason = DLL_PROCESS_DETACH then
  begin
    // Your finalization code here.
  end;
end;

begin
  DLLProc := @DLLHandler;
  // Your initialization code here.
end.


