//**************************************************************************//
// Plugins Interface version 1.5.6.                                         //
//                                                                          //
// Interface Pascal unit. Include this file into your plugin Delphi project.//
//                                                                          //
// Author: Giovanni "EvilCow" Di Sirio                                      //
//**************************************************************************//
unit PluginsInterface;

interface

uses
  Windows;
  
const
  MAX_POINTERS = 16;

type

  // Players data structure.
  TPlayerData = packed record
    Cnt: Integer;                       // Duplicate nicknames counter.
    // You can attach custom player data to the player structure by using one of
    // the following pointers, allocate an index for your plugin with AllocateIndex
    // API. If you link here a memory block you must free the memory in the
    // OnDisconnect event handler.
    Pointers: array [0..MAX_POINTERS - 1] of Pointer;
    // Player data.
    Id: DWord;                          // Player Id (assigned at connect).
    Name: array [0..31] of Char;        // Player name.
    Playing: LongBool;                  // True if playing, false if in lobby.
    Kills: Integer;                     // Kills (cleared at leave).
    Deaths: Integer;                    // Deaths (cleared at leave).
    Suicides: Integer;                  // Suicides in current mission.
    StreakKills: Integer;
    StreakDeaths: Integer;
    TeamKills: Integer;                 // Teamkills in current mission.
    Joins: Integer;                     // Number of Joins in current mission.
    Team: Integer;                      // 0 = unknown.
    MechName: array [0..31] of Char;    // (initialized ad mission start).
    MechTonnage: Integer;               // (initialized ad mission start).
    MechValue: Integer;                 // (initialized ad mission start).
    IsAdmin: LongBool;                  // True if public admin status.
    Ignore: LongBool;                   // Not currently used.
    BadWordsCounter: Integer;           // Bad words counter.
    // The structure will grow by appending more fields here.
  end;

  TPlayerDataPointer = ^TPlayerData;

  // Server configuration structure.
  TServerData = packed record
    Name: array [0..31] of Char;        // Server name.
    Password: array [0..31] of Char;    // Server password.
    MaxPlayers: Integer;                // Max number of players.
    ForceFirstPersonView: Integer;      // -1 Default, 0=disabled, 1=enabled.
    LimitedAmmunitions: Integer;        // -1 Default, 0=disabled, 1=enabled.
    HeatManagement: Integer;            // -1 Default, 0=disabled, 1=enabled.
    DeadMechsCantTalk: Integer;         // -1 Default, 0=disabled, 1=enabled.
    DeadMechsCantSee: Integer;          // -1 Default, 0=disabled, 1=enabled.
    DelayBetweenMaps: array [0..15] of Char;
    AllowJoinInProgress: Integer;       // -1 Default, 0=disabled, 1=enabled.
    JoinTimeLimit: array [0..15] of Char;
    // The structure will grow by appending more fields here.
  end;

  // Mission data structure.
  TMissionData = packed record
    Name: array [0..31] of Char;        // Mission name.
    Mission: array [0..31] of Char;     // Mission type (example: Team Battle).
    TeamMission: LongBool;              // True if a team game.
    // The structure will grow by appending more fields here.
  end;

  TGetConfigStringAPI = procedure(Section, Key: PChar; Buffer:
                                  PChar; Len: Integer); stdcall;
  TPrintAPI = procedure(Msg: PChar); stdcall;
  TKickAPI = procedure(Name: PChar); stdcall;
  TBanAPI = procedure(Name: PChar); stdcall;
  TChangeMapAPI = procedure(Name: PChar); stdcall;
  TStopMapAPI = procedure; stdcall;
  TStartMapAPI = procedure; stdcall;
  TIsMissionRunningAPI = function: LongBool; stdcall;
  TIsMissionFormingAPI = function: LongBool; stdcall;
  TGetPlayersCountAPI = function: Integer; stdcall;
  TGetPlayerDataAPI = function(Index: Integer): TPlayerDataPointer; stdcall;
  TAllocateIndexAPI = function: Integer; stdcall;     // -1 = Out of indexes.
  TRebootAPI = procedure; stdcall;

  TMonitorServices = packed record
    GetConfigString: TGetConfigStringAPI;
    Print: TPrintAPI;
    Kick: TKickAPI;
    Ban: TBanAPI;
    ChangeMap: TChangeMapAPI;
    StopMap: TStopMapAPI;
    StartMap: TStartMapAPI;
    IsMissionRunning: TIsMissionRunningAPI;
    IsMissionForming: TIsMissionFormingAPI;
    GetPlayersCount: TGetPlayersCountAPI;
    GetPlayerData: TGetPlayerDataAPI;
    AllocateIndex: TAllocateIndexAPI;
    Reboot: TRebootAPI;
    // The structure will grow by appending more fields here.
  end;

implementation

end.
